@@ -1,18 +1,30 @@
-from typing import List, AnyStr
+"""
+rumydata row rules
+
+These rules are applied to header rows and are generally not intended to be
+used directly. These rules ensure that the headers are named as expected, is
+not missing any names, or containing any extras.
+"""
+
+from typing import List
 
 from rumydata import exception as ex
 from rumydata.base import BaseRule
 
 
 class Rule(BaseRule):
+    """ Header Rule """
+
     def __init__(self, columns):
         self.definition = columns.definition
 
-    def prepare(self, data: List[AnyStr]) -> tuple:
+    def prepare(self, data: List[str]) -> tuple:
         return data,
 
 
 class NoExtra(Rule):
+    """ No extra header elements Rule """
+
     exception_class = ex.UnexpectedColumnError
 
     def evaluator(self):
@@ -23,6 +35,8 @@ class NoExtra(Rule):
 
 
 class NoMissing(Rule):
+    """ No missing header elements Rule """
+
     exception_class = ex.MissingColumnError
 
     def evaluator(self):
@@ -33,6 +47,7 @@ class NoMissing(Rule):
 
 
 class NoDuplicate(Rule):
+    """ No duplicate header elements Rule """
     exception_class = ex.DuplicateColumnError
 
     def evaluator(self):
@@ -43,6 +58,8 @@ class NoDuplicate(Rule):
 
 
 class ColumnOrder(Rule):
+    """ Fixed header element order Rule """
+
     exception_class = ex.DataError
 
     def evaluator(self):
