@@ -1,17 +1,29 @@
-from typing import List, AnyStr
+"""
+rumydata row rules
+
+These rules are applied to entire rows and are generally not intended to be
+used directly. They accomplish things like ensuring that the entire row contains
+the expected number of values, before attempting to validate individual cells.
+"""
+
+from typing import List
 
 from rumydata import exception as ex
 from rumydata.base import BaseRule
 
 
 class Rule(BaseRule):
+    """ Row Rule """
+
     exception_class = ex.RowComparisonError
 
-    def prepare(self, data: List[AnyStr]) -> tuple:
+    def prepare(self, data: List[str]) -> tuple:
         return data,
 
 
 class RowLengthLTE(Rule):
+    """ Row length less than or equal to Rule """
+
     exception_class = ex.RowLengthError
 
     def __init__(self, columns_length):
@@ -25,6 +37,8 @@ class RowLengthLTE(Rule):
 
 
 class RowLengthGTE(Rule):
+    """ Row greater than or equal to Rule """
+
     exception_class = ex.RowLengthError
 
     def __init__(self, columns_length):
